summaryrefslogtreecommitdiff
path: root/config.h
diff options
context:
space:
mode:
Diffstat (limited to 'config.h')
-rw-r--r--config.h12
1 files changed, 7 insertions, 5 deletions
diff --git a/config.h b/config.h
index 7664be78..35d6fd1a 100644
--- a/config.h
+++ b/config.h
@@ -4,7 +4,7 @@
* See the main source file 'xineliboutput.c' for copyright information and
* how to reach the author.
*
- * $Id: config.h,v 1.37 2008-02-20 03:25:11 phintuka Exp $
+ * $Id: config.h,v 1.38 2008-03-13 22:09:23 phintuka Exp $
*
*/
@@ -278,10 +278,12 @@ class config_t {
int autocrop_subs;
// (video) software scaling
- int swscale; // enable/disable
- int swscale_downscale; // allow downscaling
- int swscale_width; // output video width
- int swscale_height; // output video height
+ int swscale; // enable/disable
+ int swscale_change_aspect; // change video aspect ratio
+ int swscale_resize; // change video size
+ int swscale_width; // output video width
+ int swscale_height; // output video height
+ int swscale_downscale; // allow downscaling
// sharpen / soften post plugin
int unsharp; // enable / disable